==> formx-0.3.0.tar.gz: lib/src/interface/text_form_field_copy.dart <==
// ignore_for_file: deprecated_member_use, public_member_api_docs

// import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
// import 'dart:ui' as ui show BoxHeightStyle, BoxWidthStyle;

/// A copiable immutable [TextFormField] interface.
///
/// Unfortunately, `TextFormField` is not a copiable immutable class.
/// This is a immutable copy of the original `TextFormField` constructor,
/// which is used in `TextFormxField` and `TextFormxField.copyWith`.
///
/// Note: The class is not made abstract for tests purposes.
class TextFormFieldCopy extends StatefulWidget {
  /// An exact copy of [TextFormField.new] constructor.
  const TextFormFieldCopy({
    super.key,
    this.controller,
    this.initialValue,
    this.focusNode,
    this.decoration = const InputDecoration(),
    this.keyboardType,
    this.textCapitalization = TextCapitalization.none,
    this.textInputAction,
    this.style,
    this.strutStyle,
    this.textDirection,
    this.textAlign = TextAlign.start,
    this.textAlignVertical,
    this.autofocus = false,
    this.readOnly = false,
    this.toolbarOptions,
    this.showCursor,
    this.obscuringCharacter = '•',
    this.obscureText = false,
    this.autocorrect = true,
    this.smartDashesType,
    this.smartQuotesType,
    this.enableSuggestions = true,
    this.maxLengthEnforcement,
    this.maxLines = 1,
    this.minLines,
    this.expands = false,
    this.maxLength,
    this.onChanged,
    this.onTap,
    // this.onTapOutside,
    this.onEditingComplete,
    this.onFieldSubmitted,
    this.onSaved,
    this.validator,
    this.inputFormatters,
    this.enabled,
    this.cursorWidth = 2.0,
    this.cursorHeight,
    this.cursorRadius,
    this.cursorColor,
    this.keyboardAppearance,
    this.scrollPadding = const EdgeInsets.all(20),
    this.enableInteractiveSelection,
    this.selectionControls,
    this.buildCounter,
    this.scrollPhysics,
    this.autofillHints,
    this.autovalidateMode,
    this.scrollController,
    this.restorationId,
    this.enableIMEPersonalizedLearning = true,
    this.mouseCursor,
    // this.contextMenuBuilder = _defaultContextMenuBuilder,
    // this.spellCheckConfiguration,
    // this.magnifierConfiguration,
    // this.undoController,
    // this.onAppPrivateCommand,
    // this.cursorOpacityAnimates,
    // this.selectionHeightStyle = ui.BoxHeightStyle.tight,
    // this.selectionWidthStyle = ui.BoxWidthStyle.tight,
    // this.dragStartBehavior = DragStartBehavior.start,
    // this.contentInsertionConfiguration,
    // this.clipBehavior = Clip.hardEdge,
    // this.scribbleEnabled = true,
    // this.canRequestFocus = true,
  });

  final TextEditingController? controller;
  final String? initialValue;
  final FocusNode? focusNode;
  final InputDecoration? decoration;
  final TextInputType? keyboardType;
  final TextCapitalization textCapitalization;
  final TextInputAction? textInputAction;
  final TextStyle? style;
  final StrutStyle? strutStyle;
  final TextDirection? textDirection;
  final TextAlign textAlign;
  final TextAlignVertical? textAlignVertical;
  final bool autofocus;
  final bool readOnly;
  final ToolbarOptions? toolbarOptions;
  final bool? showCursor;
  final String obscuringCharacter;
  final bool obscureText;
  final bool autocorrect;
  final SmartDashesType? smartDashesType;
  final SmartQuotesType? smartQuotesType;
  final bool enableSuggestions;
  final MaxLengthEnforcement? maxLengthEnforcement;
  final int? maxLines;
  final int? minLines;
  final bool expands;
  final int? maxLength;
  final ValueChanged<String>? onChanged;
  final GestureTapCallback? onTap;

  // |- Flutter 3.7.0 -|
  // final TapRegionCallback? onTapOutside;
  // |- Flutter 3.7.0 -|

  final VoidCallback? onEditingComplete;
  final ValueChanged<String>? onFieldSubmitted;
  final FormFieldSetter<String>? onSaved;
  final FormFieldValidator<String>? validator;
  final List<TextInputFormatter>? inputFormatters;
  final bool? enabled;
  final double cursorWidth;
  final double? cursorHeight;
  final Radius? cursorRadius;
  final Color? cursorColor;
  final Brightness? keyboardAppearance;
  final EdgeInsets scrollPadding;
  final bool? enableInteractiveSelection;
  final TextSelectionControls? selectionControls;
  final InputCounterWidgetBuilder? buildCounter;
  final ScrollPhysics? scrollPhysics;
  final Iterable<String>? autofillHints;
  final AutovalidateMode? autovalidateMode;
  final ScrollController? scrollController;
  final String? restorationId;
  final bool enableIMEPersonalizedLearning;
  final MouseCursor? mouseCursor;

  // |- Flutter 3.7.0 -|
  // final EditableTextContextMenuBuilder? contextMenuBuilder;
  // |- Flutter 3.7.0 -|

  // |- Flutter 3.10.0 -|
  // final SpellCheckConfiguration? spellCheckConfiguration;
  // final TextMagnifierConfiguration? magnifierConfiguration;
  // |- Flutter 3.10.0 -|

  // |- Flutter 3.13.0 -|
  // final UndoHistoryController? undoController;
  // final AppPrivateCommandCallback? onAppPrivateCommand;
  // final bool? cursorOpacityAnimates;
  // final ui.BoxHeightStyle selectionHeightStyle;
  // final ui.BoxWidthStyle selectionWidthStyle;
  // final DragStartBehavior dragStartBehavior;
  // final ContentInsertionConfiguration? contentInsertionConfiguration;
  // final Clip clipBehavior;
  // final bool scribbleEnabled;
  // final bool canRequestFocus;
  // |- Flutter 3.13.0 -|

  // |- Flutter 3.7.0 -|
  // static Widget _defaultContextMenuBuilder(
  //     BuildContext context, EditableTextState editableTextState) {
  //   return AdaptiveTextSelectionToolbar.editableText(
  //     editableTextState: editableTextState,
  //   );
  // }
  // |- Flutter 3.7.0 -|

  @override
  // ignore: no_logic_in_create_state
  State<StatefulWidget> createState() => throw UnimplementedError();

  TextFormField toTextFormField(Key? key) {
    return TextFormField(
      key: key,
      controller: controller,
      initialValue: initialValue,
      focusNode: focusNode,
      decoration: decoration,
      keyboardType: keyboardType,
      textCapitalization: textCapitalization,
      textInputAction: textInputAction,
      style: style,
      strutStyle: strutStyle,
      textDirection: textDirection,
      textAlign: textAlign,
      textAlignVertical: textAlignVertical,
      autofocus: autofocus,
      readOnly: readOnly,
      toolbarOptions: toolbarOptions,
      showCursor: showCursor,
      obscuringCharacter: obscuringCharacter,
      obscureText: obscureText,
      autocorrect: autocorrect,
      smartDashesType: smartDashesType,
      smartQuotesType: smartQuotesType,
      enableSuggestions: enableSuggestions,
      maxLengthEnforcement: maxLengthEnforcement,
      maxLines: maxLines,
      minLines: minLines,
      expands: expands,
      maxLength: maxLength,
      onChanged: onChanged,
      onTap: onTap,
      // onTapOutside: onTapOutside,
      onEditingComplete: onEditingComplete,
      onFieldSubmitted: onFieldSubmitted,
      onSaved: onSaved,
      validator: validator,
      inputFormatters: inputFormatters,
      enabled: enabled,
      cursorWidth: cursorWidth,
      cursorHeight: cursorHeight,
      cursorRadius: cursorRadius,
      cursorColor: cursorColor,
      keyboardAppearance: keyboardAppearance,
      scrollPadding: scrollPadding,
      enableInteractiveSelection: enableInteractiveSelection,
      selectionControls: selectionControls,
      buildCounter: buildCounter,
      scrollPhysics: scrollPhysics,
      autofillHints: autofillHints,
      autovalidateMode: autovalidateMode,
      scrollController: scrollController,
      restorationId: restorationId,
      enableIMEPersonalizedLearning: enableIMEPersonalizedLearning,
      mouseCursor: mouseCursor,
      // contextMenuBuilder: contextMenuBuilder,
      // spellCheckConfiguration: spellCheckConfiguration,
      // magnifierConfiguration: magnifierConfiguration,
      // undoController: undoController,
      // onAppPrivateCommand: onAppPrivateCommand,
      // cursorOpacityAnimates: cursorOpacityAnimates,
      // selectionHeightStyle: selectionHeightStyle,
      // selectionWidthStyle: selectionWidthStyle,
      // dragStartBehavior: dragStartBehavior,
      // contentInsertionConfiguration: contentInsertionConfiguration,
      // clipBehavior: clipBehavior,
      // scribbleEnabled: scribbleEnabled,
      // canRequestFocus: canRequestFocus,
    );
  }
}

// ignore: avoid_implementing_value_types
class TextFormFieldRequired extends TextFormFieldCopy implements TextFormField {
  const TextFormFieldRequired({
    required super.key,
    required super.controller,
    required super.initialValue,
    required super.focusNode,
    required super.decoration,
    required super.keyboardType,
    required super.textCapitalization,
    required super.textInputAction,
    required super.style,
    required super.strutStyle,
    required super.textDirection,
    required super.textAlign,
    required super.textAlignVertical,
    required super.autofocus,
    required super.readOnly,
    required super.toolbarOptions,
    required super.showCursor,
    required super.obscuringCharacter,
    required super.obscureText,
    required super.autocorrect,
    required super.smartDashesType,
    required super.smartQuotesType,
    required super.enableSuggestions,
    required super.maxLengthEnforcement,
    required super.maxLines,
    required super.minLines,
    required super.expands,
    required super.maxLength,
    required super.onChanged,
    required super.onTap,
    // required super.onTapOutside,
    required super.onEditingComplete,
    required super.onFieldSubmitted,
    required super.onSaved,
    required super.validator,
    required super.inputFormatters,
    required super.enabled,
    required super.cursorWidth,
    required super.cursorHeight,
    required super.cursorRadius,
    required super.cursorColor,
    required super.keyboardAppearance,
    required super.scrollPadding,
    required super.enableInteractiveSelection,
    required super.selectionControls,
    required super.buildCounter,
    required super.scrollPhysics,
    required super.autofillHints,
    required super.autovalidateMode,
    required super.scrollController,
    required super.restorationId,
    required super.enableIMEPersonalizedLearning,
    required super.mouseCursor,
    // required super.contextMenuBuilder,
    // required super.spellCheckConfiguration,
    // required super.magnifierConfiguration,
    // required super.undoController,
    // required super.onAppPrivateCommand,
    // required super.cursorOpacityAnimates,
    // required super.selectionHeightStyle = ui.BoxHeightStyle.tight,
    // required super.selectionWidthStyle = ui.BoxWidthStyle.tight,
    // required super.dragStartBehavior = DragStartBehavior.start,
    // required super.contentInsertionConfiguration,
    // required super.clipBehavior = Clip.hardEdge,
    // required super.scribbleEnabled = true,
    // required super.canRequestFocus = true,
  });

  @override
  AutovalidateMode get autovalidateMode => throw UnimplementedError();

  @override
  FormFieldBuilder<String> get builder => throw UnimplementedError();

  @override
  bool get enabled => throw UnimplementedError();

  @override
  // ignore: no_logic_in_create_state
  FormFieldState<String> createState() => throw UnimplementedError();
}

==> formx-0.3.7.tar.gz: lib/src/interface/text_form_field_copy.dart <==
// ignore_for_file: deprecated_member_use, public_member_api_docs, require_trailing_commas, lines_longer_than_80_chars

// import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
// import 'dart:ui' as ui show BoxHeightStyle, BoxWidthStyle;

/// A copiable immutable [TextFormField] interface.
///
/// Unfortunately, `TextFormField` is not a copiable immutable class.
/// This is a immutable copy of the original `TextFormField` constructor,
/// which is used in `TextFormxField` and `TextFormxField.copyWith`.
///
/// Note: The class is not made abstract for tests purposes.
class TextFormFieldCopy extends StatefulWidget {
  /// An exact copy of [TextFormField.new] constructor.
  const TextFormFieldCopy({
    super.key,
    this.controller,
    this.initialValue,
    this.focusNode,
    this.decoration = const InputDecoration(),
    this.keyboardType,
    this.textCapitalization = TextCapitalization.none,
    this.textInputAction,
    this.style,
    this.strutStyle,
    this.textDirection,
    this.textAlign = TextAlign.start,
    this.textAlignVertical,
    this.autofocus = false,
    this.readOnly = false,
    this.toolbarOptions,
    this.showCursor,
    this.obscuringCharacter = '•',
    this.obscureText = false,
    this.autocorrect = true,
    this.smartDashesType,
    this.smartQuotesType,
    this.enableSuggestions = true,
    this.maxLengthEnforcement,
    this.maxLines = 1,
    this.minLines,
    this.expands = false,
    this.maxLength,
    this.onChanged,
    this.onTap,
    this.onTapOutside,
    this.onEditingComplete,
    this.onFieldSubmitted,
    this.onSaved,
    this.validator,
    this.inputFormatters,
    this.enabled,
    this.cursorWidth = 2.0,
    this.cursorHeight,
    this.cursorRadius,
    this.cursorColor,
    this.keyboardAppearance,
    this.scrollPadding = const EdgeInsets.all(20),
    this.enableInteractiveSelection,
    this.selectionControls,
    this.buildCounter,
    this.scrollPhysics,
    this.autofillHints,
    this.autovalidateMode,
    this.scrollController,
    this.restorationId,
    this.enableIMEPersonalizedLearning = true,
    this.mouseCursor,
    this.contextMenuBuilder = _defaultContextMenuBuilder,
    // this.spellCheckConfiguration,
    // this.magnifierConfiguration,
    // this.undoController,
    // this.onAppPrivateCommand,
    // this.cursorOpacityAnimates,
    // this.selectionHeightStyle = ui.BoxHeightStyle.tight,
    // this.selectionWidthStyle = ui.BoxWidthStyle.tight,
    // this.dragStartBehavior = DragStartBehavior.start,
    // this.contentInsertionConfiguration,
    // this.clipBehavior = Clip.hardEdge,
    // this.scribbleEnabled = true,
    // this.canRequestFocus = true,
  });

  final TextEditingController? controller;
  final String? initialValue;
  final FocusNode? focusNode;
  final InputDecoration? decoration;
  final TextInputType? keyboardType;
  final TextCapitalization textCapitalization;
  final TextInputAction? textInputAction;
  final TextStyle? style;
  final StrutStyle? strutStyle;
  final TextDirection? textDirection;
  final TextAlign textAlign;
  final TextAlignVertical? textAlignVertical;
  final bool autofocus;
  final bool readOnly;
  final ToolbarOptions? toolbarOptions;
  final bool? showCursor;
  final String obscuringCharacter;
  final bool obscureText;
  final bool autocorrect;
  final SmartDashesType? smartDashesType;
  final SmartQuotesType? smartQuotesType;
  final bool enableSuggestions;
  final MaxLengthEnforcement? maxLengthEnforcement;
  final int? maxLines;
  final int? minLines;
  final bool expands;
  final int? maxLength;
  final ValueChanged<String>? onChanged;
  final GestureTapCallback? onTap;

  // |- Flutter 3.7.0 -|
  final TapRegionCallback? onTapOutside;
  // |- Flutter 3.7.0 -|

  final VoidCallback? onEditingComplete;
  final ValueChanged<String>? onFieldSubmitted;
  final FormFieldSetter<String>? onSaved;
  final FormFieldValidator<String>? validator;
  final List<TextInputFormatter>? inputFormatters;
  final bool? enabled;
  final double cursorWidth;
  final double? cursorHeight;
  final Radius? cursorRadius;
  final Color? cursorColor;
  final Brightness? keyboardAppearance;
  final EdgeInsets scrollPadding;
  final bool? enableInteractiveSelection;
  final TextSelectionControls? selectionControls;
  final InputCounterWidgetBuilder? buildCounter;
  final ScrollPhysics? scrollPhysics;
  final Iterable<String>? autofillHints;
  final AutovalidateMode? autovalidateMode;
  final ScrollController? scrollController;
  final String? restorationId;
  final bool enableIMEPersonalizedLearning;
  final MouseCursor? mouseCursor;

  // |- Flutter 3.7.0 -|
  final EditableTextContextMenuBuilder? contextMenuBuilder;
  // |- Flutter 3.7.0 -|

  // |- Flutter 3.10.0 -|
  // final SpellCheckConfiguration? spellCheckConfiguration;
  // final TextMagnifierConfiguration? magnifierConfiguration;
  // |- Flutter 3.10.0 -|

  // |- Flutter 3.13.0 -|
  // final UndoHistoryController? undoController;
  // final AppPrivateCommandCallback? onAppPrivateCommand;
  // final bool? cursorOpacityAnimates;
  // final ui.BoxHeightStyle selectionHeightStyle;
  // final ui.BoxWidthStyle selectionWidthStyle;
  // final DragStartBehavior dragStartBehavior;
  // final ContentInsertionConfiguration? contentInsertionConfiguration;
  // final Clip clipBehavior;
  // final bool scribbleEnabled;
  // final bool canRequestFocus;
  // |- Flutter 3.13.0 -|

  // |- Flutter 3.7.0 -|
  static Widget _defaultContextMenuBuilder(
      BuildContext context, EditableTextState editableTextState) {
    return AdaptiveTextSelectionToolbar.editableText(
      editableTextState: editableTextState,
    );
  }
  // |- Flutter 3.7.0 -|

  @override
  // ignore: no_logic_in_create_state
  State<StatefulWidget> createState() => throw UnimplementedError();

  TextFormField toTextFormField(Key? key) {
    return TextFormField(
      key: key,
      controller: controller,
      initialValue: initialValue,
      focusNode: focusNode,
      decoration: decoration,
      keyboardType: keyboardType,
      textCapitalization: textCapitalization,
      textInputAction: textInputAction,
      style: style,
      strutStyle: strutStyle,
      textDirection: textDirection,
      textAlign: textAlign,
      textAlignVertical: textAlignVertical,
      autofocus: autofocus,
      readOnly: readOnly,
      toolbarOptions: toolbarOptions,
      showCursor: showCursor,
      obscuringCharacter: obscuringCharacter,
      obscureText: obscureText,
      autocorrect: autocorrect,
      smartDashesType: smartDashesType,
      smartQuotesType: smartQuotesType,
      enableSuggestions: enableSuggestions,
      maxLengthEnforcement: maxLengthEnforcement,
      maxLines: maxLines,
      minLines: minLines,
      expands: expands,
      maxLength: maxLength,
      onChanged: onChanged,
      onTap: onTap,
      onTapOutside: onTapOutside,
      onEditingComplete: onEditingComplete,
      onFieldSubmitted: onFieldSubmitted,
      onSaved: onSaved,
      validator: validator,
      inputFormatters: inputFormatters,
      enabled: enabled,
      cursorWidth: cursorWidth,
      cursorHeight: cursorHeight,
      cursorRadius: cursorRadius,
      cursorColor: cursorColor,
      keyboardAppearance: keyboardAppearance,
      scrollPadding: scrollPadding,
      enableInteractiveSelection: enableInteractiveSelection,
      selectionControls: selectionControls,
      buildCounter: buildCounter,
      scrollPhysics: scrollPhysics,
      autofillHints: autofillHints,
      autovalidateMode: autovalidateMode,
      scrollController: scrollController,
      restorationId: restorationId,
      enableIMEPersonalizedLearning: enableIMEPersonalizedLearning,
      mouseCursor: mouseCursor,
      contextMenuBuilder: contextMenuBuilder,
      // spellCheckConfiguration: spellCheckConfiguration,
      // magnifierConfiguration: magnifierConfiguration,
      // undoController: undoController,
      // onAppPrivateCommand: onAppPrivateCommand,
      // cursorOpacityAnimates: cursorOpacityAnimates,
      // selectionHeightStyle: selectionHeightStyle,
      // selectionWidthStyle: selectionWidthStyle,
      // dragStartBehavior: dragStartBehavior,
      // contentInsertionConfiguration: contentInsertionConfiguration,
      // clipBehavior: clipBehavior,
      // scribbleEnabled: scribbleEnabled,
      // canRequestFocus: canRequestFocus,
    );
  }
}
